@@ -1,14 +1,20 @@
 
 import uuid
 
-from .conf import get_conversejs_settings, CONVERSEJS_AUTO_REGISTER
+from . import conf
 from .models import XMPPAccount
 from .boshclient import BOSHClient
 from .register import register_account
 
 
 def get_conversejs_context(context, xmpp_login=False):
-    context.update(get_conversejs_settings())
+
+    context['CONVERSEJS_ENABLED'] = conf.CONVERSEJS_ENABLED
+
+    if not conf.CONVERSEJS_ENABLED:
+        return context
+
+    context.update(conf.get_conversejs_settings())
 
     request = context.get('request')
 
@@ -18,7 +24,7 @@ def get_conversejs_context(context, xmpp_login=False):
     try:
         xmpp_account = XMPPAccount.objects.get(user=request.user.pk)
     except XMPPAccount.DoesNotExist:
-        jid_domain = CONVERSEJS_AUTO_REGISTER
+        jid_domain = conf.CONVERSEJS_AUTO_REGISTER
         if not jid_domain:
             return context
 
@@ -38,6 +44,8 @@ def get_conversejs_context(context, xmpp_login=False):
     bosh = BOSHClient(xmpp_account.jid, xmpp_account.password,
                       context['CONVERSEJS_BOSH_SERVICE_URL'])
     jid, sid, rid = bosh.get_credentials()
+    bosh.close_connection()
+
     context.update({'jid': jid, 'sid': sid, 'rid': rid})
 
     return context
